@@ -1,8 +1,5 @@
 package Git::Repository;
-{
-  $Git::Repository::VERSION = '1.309';
-}
-
+$Git::Repository::VERSION = '1.313';
 use warnings;
 use strict;
 use 5.006;
@@ -289,8 +286,8 @@ sub version_ge {
 
 # ABSTRACT: Perl interface to Git repositories
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -299,7 +296,7 @@ Git::Repository - Perl interface to Git repositories
 
 =head1 VERSION
 
-version 1.309
+version 1.313
 
 =head1 SYNOPSIS
 
@@ -322,12 +319,16 @@ version 1.309
     Git::Repository->run( clone => $url, $dir, ... );
     $r = Git::Repository->new( work_tree => $dir );
 
-    # run commands
-    # - get the full output (no errput)
-    $output = $r->run(@cmd);
+    # provide an option hash for Git::Repository::Command
+    # (see Git::Repository::Command for all available options)
+    $r = Git::Repository->new( ..., \%options );
 
-    # - get the full output as a list of lines (no errput)
-    @output = $r->run(@cmd);
+    # run commands
+    # - get the full output (no errput) passing options for this command only
+    $output = $r->run( @cmd, \%options );
+
+    # - get the full output as a list of lines (no errput), with options
+    @output = $r->run( @cmd, \%options );
 
     # - process the output with callbacks
     $output = $r->run( @cmd, sub {...} );
@@ -335,7 +336,7 @@ version 1.309
 
     # - obtain a Git::Repository::Command object
     #   (see Git::Repository::Command for details)
-    $cmd = $r->command(@cmd);
+    $cmd = $r->command( @cmd, \%options );
 
     # obtain version information
     my $version = $r->version();
@@ -374,7 +375,9 @@ See L<Git::Repository::Tutorial> for more code examples.
 
 =head1 CONSTRUCTOR
 
-=head2 new( %args, $options )
+=head2 new
+
+    Git::Repository->new( %args, $options );
 
 Create a new L<Git::Repository> object, based on an existing Git repository.
 
@@ -412,16 +415,16 @@ corresponding L<Git::Repository> instance.
 
 So this:
 
-    my $options = {
-        git => '/path/to/some/other/git',
-        env => {
-            GIT_COMMITTER_EMAIL => 'book@cpan.org',
-            GIT_COMMITTER_NAME  => 'Philippe Bruhat (BooK)',
-        },
-    };
     my $r = Git::Repository->new(
+        # parameters
         work_tree => $dir,
-        $options
+        # options
+        {   git => '/path/to/some/other/git',
+            env => {
+                GIT_COMMITTER_EMAIL => 'book@cpan.org',
+                GIT_COMMITTER_NAME  => 'Philippe Bruhat (BooK)',
+            },
+        }
     );
 
 is equivalent to explicitly passing the option hash to each
@@ -429,6 +432,10 @@ C<run()> or C<command()> call.
 The documentation for L<Git::Repository::Command> lists all
 available options.
 
+Note that Git::Repository and L<Git::Repository::Command> take
+great care in finding the option hash wherever it may be in C<@_>,
+and to merge multiple option hashes if more than one is provided.
+
 It probably makes no sense to set the C<input> option in C<new()>,
 but L<Git::Repository> won't stop you.
 Note that on some systems, some git commands may close standard input
@@ -454,7 +461,10 @@ pointing to it, simply do it in two steps:
 
 L<Git::Repository> supports the following methods:
 
-=head2 command( @cmd )
+=head2 command
+
+    Git::Repository->command( @cmd );
+    $r->command( @cmd );
 
 Runs the git sub-command and options, and returns a L<Git::Repository::Command>
 object pointing to the sub-process running the command.
@@ -462,7 +472,10 @@ object pointing to the sub-process running the command.
 As described in the L<Git::Repository::Command> documentation, C<@cmd>
 may also contain a hashref containing options for the command.
 
-=head2 run( @cmd )
+=head2 run
+
+    Git::Repository->run( @cmd );
+    $r->run( @cmd );
 
 Runs the command and returns the output as a string in scalar context,
 or as a list of lines in list context. Also accepts a hashref of options.
@@ -483,20 +496,20 @@ the C<fatal> option (see L<Git::Repository::Command> for details).
 The exit status of the command that was just run is accessible as usual
 using C<<< $? >> 8 >>>. See L<perlvar> for details about C<$?>.
 
-=head2 git_dir()
+=head2 git_dir
 
 Returns the repository path.
 
-=head2 work_tree()
+=head2 work_tree
 
 Returns the working copy path.
 Used as current working directory by L<Git::Repository::Command>.
 
-=head2 options()
+=head2 options
 
 Return the option hash that was passed to C<< Git::Repository->new() >>.
 
-=head2 version()
+=head2 version
 
 Return the version of git, as given by C<git --version>.
 
@@ -595,12 +608,12 @@ See L<Git::Repository::Plugin> about how to create a new plugin.
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to Todd Rinalo, who wanted to add more methods to
+Thanks to Todd Rinaldo, who wanted to add more methods to
 L<Git::Repository>, which made me look for a solution that would preserve
 the minimalism of L<Git::Repository>. The C<::Plugin> interface is what
 I came up with.
 
-=head1 OTHER PERL GIT WRAPPERS
+=head1 OTHER PERL GIT WRAPPERS (a.k.a. SEE ALSO)
 
 (This section was written in June 2010. The other Git wrappers have
 probably evolved since that time.)
@@ -628,15 +641,18 @@ depending on what you're trying to achieve.
 
 =head2 Git.pm
 
-Git.pm is not on CPAN. It is usually packaged with Git, and installed with
-the system Perl libraries. Not being on CPAN makes it harder to install
-in any Perl. It makes it harder for a CPAN library to depend on it.
+Git.pm was not on CPAN in 2010. It is packaged with Git, and installed
+with the system Perl libraries. Not being on CPAN made it harder to
+install in any Perl. It made it harder for a CPAN library to depend on it.
 
 It doesn't allow calling C<git init> or C<git clone>.
 
 The C<command_bidi_pipe> function especially has problems:
 L<http://kerneltrap.org/mailarchive/git/2008/10/24/3789584>
 
+The L<Git> module from git.git was packaged as a CPAN distribution by
+MSOUTH in June 2013.
+
 =head2 Git::Class
 
 L<Git::Class>
@@ -665,6 +681,17 @@ impact most Git commands.
 
 L<Git::Sub> doesn't support working with streams.
 
+=head2 Git::Raw
+
+(This description was added for completeness in September 2014,
+upon request of the author of L<Git::Raw>.)
+
+L<Git::Raw>
+provides bindings to L<libgit2|http://libgit2.github.com/>, a pure C
+implementation of the Git core methods. Most of the functions provided by
+libgit2 are available. If you have complex workflows, or even if speed is of
+the essence, this may be a more attractive solution than shelling out to git.
+
 =head1 BUGS
 
 Since version 1.17, L<Git::Repository> delegates the actual command
@@ -719,7 +746,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2010-2013 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
@@ -727,4 +754,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
