@@ -1,8 +1,5 @@
 package Git::Repository::Plugin;
-{
-  $Git::Repository::Plugin::VERSION = '1.309';
-}
-
+$Git::Repository::Plugin::VERSION = '1.313';
 use strict;
 use warnings;
 use 5.006;
@@ -35,8 +32,8 @@ sub _keywords {
 
 # ABSTRACT: Base class for Git::Repository plugins
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -45,7 +42,7 @@ Git::Repository::Plugin - Base class for Git::Repository plugins
 
 =head1 VERSION
 
-version 1.309
+version 1.313
 
 =head1 SYNOPSIS
 
@@ -76,7 +73,9 @@ with all the methods they provide, or only a selection of them.
 
 L<Git::Repository::Plugin> provides a single method:
 
-=head2 install( @keywords )
+=head2 install
+
+    $plugin->install( @keywords );
 
 Install all keywords provided in the L<Git::Repository> namespace.
 
@@ -129,7 +128,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2010-2013 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
@@ -137,4 +136,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
